@@ -18,7 +18,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
- $Id: battstat_applet.c,v 1.49 2003/03/12 17:15:11 kevinv Exp $
+ $Id: battstat_applet.c,v 1.53 2003/07/24 02:02:45 kevinv Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -29,6 +29,7 @@
 #include <sys/ioctl.h>
 #include <sys/types.h>
 #include <sys/sysctl.h>
+#include <stdio.h>
 
 #ifdef __FreeBSD__
 #include <machine/apm_bios.h>
@@ -40,7 +41,6 @@
 #endif
 
 #include <err.h>
-#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <sys/file.h>
@@ -1202,35 +1202,6 @@ adj_value_changed_cb (GtkAdjustment *ignored, gpointer data)
    battstat->colors_changed = FALSE;
 }
 
-#if 0
-static void
-build_our_plug(StatusDocklet *docklet, GtkWidget *plug, gpointer data)
-{
-   ProgressData *battstat = data;
-   
-   battstat->eventdock = gtk_event_box_new ();
-   gtk_widget_show (battstat->eventdock);
-   gtk_container_add (GTK_CONTAINER(plug), battstat->eventdock);
-   
-   battstat->pixmapdockwid = gtk_pixmap_new ( statusimage[BATTERY], statusmask[BATTERY] );
-   
-   if(battstat->usedock) {
-      gtk_widget_show(battstat->eventdock);
-      gtk_widget_show(battstat->pixmapdockwid);
-   } else {
-      gtk_widget_hide(battstat->pixmapdockwid);    
-      gtk_widget_hide(battstat->eventdock);    
-   }
-   
-   gtk_container_add(GTK_CONTAINER(battstat->eventdock), battstat->pixmapdockwid);
-   
-   battstat->st_tip = gtk_tooltips_new ();
-   gtk_tooltips_set_tip (battstat->st_tip,
-			 battstat->eventdock,
-			 "Add code here",
-			 NULL);
-}
-#endif
 
 void
 change_size(PanelApplet *applet, gint size, gpointer data)
@@ -1247,6 +1218,35 @@ change_size(PanelApplet *applet, gint size, gpointer data)
    battstat->colors_changed=FALSE;
 }
 
+static gboolean
+button_press_cb (GtkWidget *widget, GdkEventButton *event, ProgressData *battstat)
+{
+	if (event->button == 1 && event->type == GDK_2BUTTON_PRESS) 
+		suspend_cb (NULL, battstat, NULL);
+
+	return FALSE;
+}
+
+static gboolean
+key_press_cb (GtkWidget *widget, GdkEventKey *event, ProgressData *battstat)
+{
+	switch (event->keyval) {
+	case GDK_KP_Enter:
+	case GDK_ISO_Enter:
+	case GDK_3270_Enter:
+	case GDK_Return:
+	case GDK_space:
+	case GDK_KP_Space:
+		suspend_cb (NULL, battstat, NULL);
+		return TRUE;
+
+	default:
+		break;
+	}
+
+	return FALSE;
+}
+
 
 #define GCONF_PATH ""
 
@@ -1267,14 +1267,12 @@ load_preferences(ProgressData *battstat)
   battstat->fullbattnot = panel_applet_gconf_get_bool (applet, GCONF_PATH "full_battery_notification", NULL);
   battstat->beep = panel_applet_gconf_get_bool (applet, GCONF_PATH "beep", NULL);
   battstat->draintop = panel_applet_gconf_get_bool (applet, GCONF_PATH "drain_from_top", NULL);
-  battstat->horizont = panel_applet_gconf_get_bool (applet, GCONF_PATH "horizontal", NULL);
-
+  
   battstat->showstatus = panel_applet_gconf_get_bool (applet, GCONF_PATH "show_status", NULL);
   battstat->showbattery = panel_applet_gconf_get_bool (applet, GCONF_PATH "show_battery", NULL);
   battstat->showpercent = panel_applet_gconf_get_bool (applet, GCONF_PATH "show_percent", NULL);
   battstat->suspend_cmd = panel_applet_gconf_get_string (applet, GCONF_PATH "suspend_command", NULL);
-  battstat->usedock = panel_applet_gconf_get_bool (applet, GCONF_PATH "use_dock", NULL);
-
+  
 }
 
 gint
@@ -1440,20 +1438,17 @@ create_layout(ProgressData *battstat)
 			 battstat->eventybattery,
 			 "",
 			 NULL);
-#if 0
-   statusdock = status_docklet_new();
-   
-   gtk_signal_connect(GTK_OBJECT(statusdock), "build_plug",
-		      GTK_SIGNAL_FUNC(build_our_plug),
-		      battstat);
-   status_docklet_run(STATUS_DOCKLET(statusdock));
-#endif
 
    gtk_signal_connect(GTK_OBJECT(battstat->applet),"change_orient",
 		      GTK_SIGNAL_FUNC(change_orient),
 		      battstat);
    g_signal_connect (G_OBJECT (battstat->applet), "change_size",
    		     G_CALLBACK (change_size), battstat);
+   		     
+   g_signal_connect (battstat->applet, "button_press_event",
+   			     G_CALLBACK (button_press_cb), battstat);
+   g_signal_connect (battstat->applet, "key_press_event",
+   			     G_CALLBACK (key_press_cb), battstat);
 
    return FALSE;
 }
@@ -1468,6 +1463,7 @@ battstat_applet_fill (PanelApplet *applet)
   gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/battstat.png");
   
   panel_applet_add_preferences (applet, "/schemas/apps/battstat-applet/prefs", NULL);
+  panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
 
   apm_readinfo (applet);
   
@@ -1493,6 +1489,7 @@ battstat_applet_fill (PanelApplet *applet)
   battstat->suspend_cmd = NULL;
   battstat->orienttype = panel_applet_get_orient (applet);
   battstat->panelsize = panel_applet_get_size (applet);
+  battstat->horizont = TRUE;
   
   glade_gnome_init ();
   
