@@ -72,24 +72,33 @@ gkb_prop_map_close_clicked (GkbMapDialogInfo * mdi)
   keymap = mdi->keymap;
                                                                                 
   name = g_strdup (gtk_entry_get_text (GTK_ENTRY (mdi->name_entry)));
-  if (name) {
-  	 if  (keymap->name)
-  		g_free (keymap->name);
-  	keymap->name = name;
-  }
+  if (keymap->name)
+	g_free (keymap->name);
+  if (name && name[0])
+	keymap->name = g_strdup (name);
+  else
+	keymap->name = g_strdup (_("Unknown Keyboard"));
+  if (name)
+	g_free (name);
+
   label =
     g_strdup (gtk_entry_get_text (GTK_ENTRY (mdi->label_entry)));
-  if (label) {
-  	 if  (keymap->label)
-  		g_free (keymap->label);
-  	keymap->label = label;
-  }
+  if (keymap->label)
+	g_free (keymap->label);
+  if (label && label[0])
+	keymap->label = g_strdup (label);
+  else  
+	keymap->label = g_strdup (_("?"));
+  if (label)
+	g_free (label);
+
   command =
     g_strdup (gtk_entry_get_text (GTK_ENTRY (mdi->command_entry)));
   if (command) {
   	 if  (keymap->command)
   		g_free (keymap->command);
-  	keymap->command = command;
+  	keymap->command = g_strdup (command);
+	g_free (command);
   }
   flag =
     g_strdup (g_basename
@@ -98,19 +107,15 @@ gkb_prop_map_close_clicked (GkbMapDialogInfo * mdi)
   if (flag) {
   	 if  (keymap->flag)
   		g_free (keymap->flag);
-  	keymap->flag = flag;
+  	keymap->flag = g_strdup (flag);
+	g_free (flag);
   }
                                                                               
   mdi->pbi->selected_keymap = keymap;
-                                                                                
   gkb_prop_list_reload (mdi->pbi);
-                                                                                
   gkb_apply(mdi->pbi);
-                                                                                
   gtk_widget_destroy (mdi->dialog);
-
-  applet_save_session(mdi->pbi->gkb);
-   
+  gkb_save_session (mdi->pbi->gkb);
   mdi->dialog = NULL;
 }
 
@@ -275,10 +280,12 @@ gkb_prop_map_edit (GkbPropertyBoxInfo * pbi)
 
   gtk_dialog_set_has_separator (GTK_DIALOG (mdi->dialog), FALSE);
   gtk_dialog_set_default_response (GTK_DIALOG (mdi->dialog), GTK_RESPONSE_CLOSE);
+  gtk_container_set_border_width (GTK_CONTAINER (mdi->dialog), 5);
+  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (mdi->dialog)->vbox), 2);
   gtk_window_set_resizable (GTK_WINDOW (mdi->dialog), FALSE);
 
   vbox1 = gtk_vbox_new (FALSE, 0);
-  gtk_container_set_border_width (GTK_CONTAINER (vbox1), 12);
+  gtk_container_set_border_width (GTK_CONTAINER (vbox1), 5);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (mdi->dialog)->vbox), vbox1,
                         TRUE, TRUE, 0);
 
