@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.13 2003/02/21 00:48:24 kevinv Exp $ */
+/* $Id: main.c,v 1.14 2003/07/13 23:17:52 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -20,15 +20,6 @@
 #include "gweather-dialog.h"
 #include "gweather-applet.h"
 
-static void
-initialize_info (WeatherInfo *info)
-{
-	info->main_handle = NULL;
-	info->success = FALSE;
-	info->xml = NULL;
-	info->forecasts = NULL;
-	
-}
 
 gboolean
 gweather_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
@@ -40,11 +31,12 @@ gweather_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 	gw_applet = g_new0(GWeatherApplet, 1);   
 	
 	gw_applet->applet = applet;
-	gw_applet->gweather_info = g_new0 (WeatherInfo, 1);
-	initialize_info (gw_applet->gweather_info);
-	
+	gw_applet->gweather_info = NULL;
+    	gweather_applet_create(gw_applet);
+
     	gweather_pref_load(gw_applet);
-	gweather_applet_create (gw_applet);
+    	gweather_info_load("test_path", gw_applet);
+    
     	gweather_update(gw_applet);
 
     	return TRUE;
