@@ -20,18 +20,27 @@
  */
 
 #include <config.h>
+
+#include <libgnome/gnome-help.h>
+#include <egg-screen-help.h>
+
 #include "help.h"
 
 void 
-show_help(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
+show_help (BonoboUIComponent *uic,
+	   MCData            *mcdata,
+	   const char        *verbname)
 {
     GError *error = NULL;
-    
-    gnome_help_display_desktop (NULL, "command-line", "command-line", NULL, &error);
-    if (error) {
+   
+    egg_help_display_on_screen (
+		"command-line", NULL,
+		gtk_widget_get_screen (GTK_WIDGET (mcdata->applet)),
+		&error);
+
+    if (error) { /* FIXME: this error needs to be seen by the user */
     	g_warning ("help error: %s\n", error->message);
 	g_error_free (error);
+	error = NULL;
     }
-
-    return;
 }
