@@ -629,7 +629,7 @@ show_error_dialog (MixerData *data)
 	data->error_dialog = gtk_message_dialog_new (NULL,
 					 GTK_DIALOG_DESTROY_WITH_PARENT,
 					 GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-					 ("Couldn't open mixer device %s\n"),
+					 _("Couldn't open mixer device %s\n"),
 					 data->device, NULL);
 
 	gtk_window_set_screen (GTK_WINDOW (data->error_dialog),
@@ -1282,7 +1282,7 @@ mixer_pref_cb (BonoboUIComponent *uic,
         	GtkTreeIter iter;
         	
 		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, cdata->name, 1, cdata, -1);
+		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, _(cdata->name), 1, cdata, -1);
 		if (cdata->channel == data->mixerchannel) {
 			GtkTreePath *path;
 			path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &iter);
