@@ -15,6 +15,7 @@
 G_BEGIN_DECLS
 
 #define NCPUSTATES 4
+#define NGRAPHS 5
 
 typedef struct _MultiloadApplet MultiloadApplet;
 typedef struct _LoadGraph LoadGraph;
@@ -59,7 +60,7 @@ struct _MultiloadApplet
 {
 	PanelApplet *applet;
 	
-	LoadGraph *graphs[5];
+	LoadGraph *graphs[NGRAPHS];
 	
 	GtkWidget *box;
 	
@@ -69,7 +70,7 @@ struct _MultiloadApplet
 	gboolean view_swapload;
 	gboolean view_loadavg;
 	
-	GtkWidget *check_boxes[5];
+	GtkWidget *check_boxes[NGRAPHS];
 };
 
 #include "load-graph.h"
