@@ -38,8 +38,8 @@ static const BonoboUIVerb stickynotes_applet_menu_verbs[] =
 /* Sticky Notes Icons */
 static const StickyNotesStockIcon stickynotes_icons[] =
 {
-	{ STICKYNOTES_STOCK_LOCK, STICKYNOTES_ICONDIR "/lock.png" },
-	{ STICKYNOTES_STOCK_UNLOCK, STICKYNOTES_ICONDIR "/unlock.png" },
+	{ STICKYNOTES_STOCK_LOCKED, STICKYNOTES_ICONDIR "/locked.png" },
+	{ STICKYNOTES_STOCK_UNLOCKED, STICKYNOTES_ICONDIR "/unlocked.png" },
 	{ STICKYNOTES_STOCK_CLOSE, STICKYNOTES_ICONDIR "/close.png" },
 	{ STICKYNOTES_STOCK_RESIZE_SE, STICKYNOTES_ICONDIR "/resize_se.png" },
 	{ STICKYNOTES_STOCK_RESIZE_SW, STICKYNOTES_ICONDIR "/resize_sw.png" }
@@ -67,7 +67,8 @@ static gboolean stickynotes_applet_factory(PanelApplet *panel_applet, const gcha
 }
 
 /* Sticky Notes applet factory */
-PANEL_APPLET_BONOBO_FACTORY("OAFIID:GNOME_StickyNotesApplet_Factory", PANEL_TYPE_APPLET, PACKAGE, VERSION, stickynotes_applet_factory, NULL);
+PANEL_APPLET_BONOBO_FACTORY("OAFIID:GNOME_StickyNotesApplet_Factory", PANEL_TYPE_APPLET, "stickynotes_applet", VERSION,
+			    stickynotes_applet_factory, NULL);
 
 /* Create and initalize global sticky notes instance */
 void stickynotes_applet_init()
@@ -82,7 +83,6 @@ void stickynotes_applet_init()
 	stickynotes->tooltips = gtk_tooltips_new();
 
 	stickynotes_applet_init_icons();
-	stickynotes_applet_init_about();
 	stickynotes_applet_init_prefs();
 
 	/* Set default icon for all sticky note windows */
@@ -121,32 +121,10 @@ void stickynotes_applet_init_icons()
 	}
 
 	gtk_icon_factory_add_default(icon_factory);
-	gtk_icon_size_register(STICKYNOTES_ICON_SIZE_NAME, STICKYNOTES_ICON_SIZE_VALUE, STICKYNOTES_ICON_SIZE_VALUE);
 
 	g_object_unref(G_OBJECT(icon_factory));
 }
 
-void stickynotes_applet_init_about()
-{
-	stickynotes->about = glade_xml_new(GLADE_PATH, "about_dialog", NULL);
-
-	stickynotes->w_about = glade_xml_get_widget(stickynotes->about, "about_dialog");
-
-	/* FIXME : Hack because libglade does not properly set these */
-	g_object_set(G_OBJECT(stickynotes->w_about), "name", _("Sticky Notes"));
-	g_object_set(G_OBJECT(stickynotes->w_about), "version", VERSION);
-	
-	{
-		GdkPixbuf *logo = gdk_pixbuf_new_from_file(STICKYNOTES_ICONDIR "/stickynotes.png", NULL);
-		g_object_set(G_OBJECT(stickynotes->w_about), "logo", logo);
-		g_object_unref(logo);
-	}
-	if (strcmp(_("translator_credits"), "translator_credits") == 0)
-		g_object_set(G_OBJECT(stickynotes->w_about), "translator_credits", NULL);
-	
-	g_signal_connect(G_OBJECT(stickynotes->w_about), "response", G_CALLBACK(about_response_cb), NULL);
-}
-
 void stickynotes_applet_init_prefs()
 {
 	stickynotes->prefs = glade_xml_new(GLADE_PATH, "preferences_dialog", NULL);
@@ -163,6 +141,7 @@ void stickynotes_applet_init_prefs()
 	stickynotes->w_prefs_force = GTK_WIDGET(&GTK_CHECK_BUTTON(glade_xml_get_widget(stickynotes->prefs, "force_default_check"))->toggle_button);
 
 	g_signal_connect(G_OBJECT(stickynotes->w_prefs), "response", G_CALLBACK(preferences_response_cb), NULL);
+	g_signal_connect(G_OBJECT(stickynotes->w_prefs), "delete-event", G_CALLBACK(preferences_delete_cb), NULL);
 	g_signal_connect_swapped(G_OBJECT(stickynotes->w_prefs_width), "value-changed", G_CALLBACK(preferences_save_cb), NULL);
 	g_signal_connect_swapped(G_OBJECT(stickynotes->w_prefs_height), "value-changed", G_CALLBACK(preferences_save_cb), NULL);
 	g_signal_connect_swapped(G_OBJECT(stickynotes->w_prefs_sys_color), "toggled", G_CALLBACK(preferences_save_cb), NULL);
@@ -172,7 +151,7 @@ void stickynotes_applet_init_prefs()
 	g_signal_connect_swapped(G_OBJECT(stickynotes->w_prefs_click), "changed", G_CALLBACK(preferences_save_cb), NULL);
 	g_signal_connect_swapped(G_OBJECT(stickynotes->w_prefs_sticky), "toggled", G_CALLBACK(preferences_save_cb), NULL);
 	g_signal_connect_swapped(G_OBJECT(stickynotes->w_prefs_force), "toggled", G_CALLBACK(preferences_save_cb), NULL);
-	
+
 	{
 		GtkSizeGroup *group = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
 
@@ -184,6 +163,35 @@ void stickynotes_applet_init_prefs()
 		g_object_unref(group);
 	}
 			
+	if (!gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/defaults/width", NULL)) {
+		gtk_widget_set_sensitive(glade_xml_get_widget(stickynotes->prefs, "width_label"), FALSE);
+		gtk_widget_set_sensitive(glade_xml_get_widget(stickynotes->prefs, "width_spin"), FALSE);
+	}
+	if (!gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/defaults/height", NULL)) {
+		gtk_widget_set_sensitive(glade_xml_get_widget(stickynotes->prefs, "height_label"), FALSE);
+		gtk_widget_set_sensitive(glade_xml_get_widget(stickynotes->prefs, "height_spin"), FALSE);
+	}
+	if (!gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/defaults/color", NULL)) {
+		gtk_widget_set_sensitive(glade_xml_get_widget(stickynotes->prefs, "color_label"), FALSE);
+		gtk_widget_set_sensitive(stickynotes->w_prefs_color, FALSE);
+	}
+	if (!gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/settings/use_system_color", NULL))
+		gtk_widget_set_sensitive(stickynotes->w_prefs_sys_color, FALSE);
+	if (!gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/defaults/font", NULL)) {
+		gtk_widget_set_sensitive(glade_xml_get_widget(stickynotes->prefs, "font_label"), FALSE);
+		gtk_widget_set_sensitive(stickynotes->w_prefs_font, FALSE);
+	}
+	if (!gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/settings/use_system_font", NULL))
+		gtk_widget_set_sensitive(stickynotes->w_prefs_sys_font, FALSE);
+	if (!gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/settings/click_behavior", NULL)) {
+		gtk_widget_set_sensitive(glade_xml_get_widget(stickynotes->prefs, "click_label"), FALSE);
+		gtk_widget_set_sensitive(stickynotes->w_prefs_click, FALSE);
+	}
+	if (!gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/settings/sticky", NULL))
+		gtk_widget_set_sensitive(stickynotes->w_prefs_sticky, FALSE);
+	if (!gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/settings/force_default", NULL))
+		gtk_widget_set_sensitive(stickynotes->w_prefs_force, FALSE);
+
 	stickynotes_applet_update_prefs();
 }
 
@@ -212,13 +220,10 @@ StickyNotesApplet * stickynotes_applet_new(PanelApplet *panel_applet)
 	bonobo_ui_component_add_listener(panel_applet_get_popup_component(panel_applet), "show", (BonoboUIListenerFn) menu_toggle_show_cb, applet);
 	bonobo_ui_component_add_listener(panel_applet_get_popup_component(panel_applet), "lock", (BonoboUIListenerFn) menu_toggle_lock_cb, applet);
 
-	gtk_widget_add_events(applet->w_applet, GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK); /* FIXME : Doesn't work */
-
 	/* Connect all signals for applet management */
 	g_signal_connect(G_OBJECT(applet->w_applet), "button-press-event", G_CALLBACK(applet_button_cb), applet);
 	g_signal_connect(G_OBJECT(applet->w_applet), "button-release-event", G_CALLBACK(applet_button_cb), applet);
 	g_signal_connect(G_OBJECT(applet->w_applet), "key-press-event", G_CALLBACK(applet_key_cb), applet);
-	g_signal_connect(G_OBJECT(applet->w_applet), "key-release-event", G_CALLBACK(applet_key_cb), applet);
 	g_signal_connect(G_OBJECT(applet->w_applet), "focus-in-event", G_CALLBACK(applet_focus_cb), applet);
 	g_signal_connect(G_OBJECT(applet->w_applet), "focus-out-event", G_CALLBACK(applet_focus_cb), applet);
 	g_signal_connect(G_OBJECT(applet->w_applet), "enter-notify-event", G_CALLBACK(applet_cross_cb), applet);
@@ -285,18 +290,25 @@ void stickynotes_applet_update_prefs()
 	gnome_color_picker_set_i16(GNOME_COLOR_PICKER(stickynotes->w_prefs_color), color.red, color.green, color.blue, 65535);
 	gnome_font_picker_set_font_name(GNOME_FONT_PICKER(stickynotes->w_prefs_font), font_str);
 
-	gtk_widget_set_sensitive(glade_xml_get_widget(stickynotes->prefs, "color_label"), !sys_color);
-	gtk_widget_set_sensitive(stickynotes->w_prefs_color, !sys_color);
-	gtk_widget_set_sensitive(glade_xml_get_widget(stickynotes->prefs, "font_label"), !sys_font);
-	gtk_widget_set_sensitive(stickynotes->w_prefs_font, !sys_font);
+	if (gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/defaults/color", NULL)) {
+		gtk_widget_set_sensitive(glade_xml_get_widget(stickynotes->prefs, "color_label"), !sys_color);
+		gtk_widget_set_sensitive(stickynotes->w_prefs_color, !sys_color);
+	}
+	if (gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/defaults/font", NULL)) {
+		gtk_widget_set_sensitive(glade_xml_get_widget(stickynotes->prefs, "font_label"), !sys_font);
+		gtk_widget_set_sensitive(stickynotes->w_prefs_font, !sys_font);
+	}
 }
 
 void stickynotes_applet_update_menus()
 {
 	gboolean visible = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/visible", NULL);
 	gboolean locked = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/locked", NULL);
+	
+	gboolean visible_writable = gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/settings/visible", NULL);
+	gboolean locked_writable = gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/settings/locked", NULL);
+	
 	gboolean inconsistent = FALSE;
-
 	gint i;
 
 	for (i = 0; i < g_list_length(stickynotes->notes) && !inconsistent; i++) {
@@ -312,7 +324,11 @@ void stickynotes_applet_update_menus()
 		
 		bonobo_ui_component_set_prop(popup, "/commands/show", "state", visible ? "1" : "0", NULL);
 		bonobo_ui_component_set_prop(popup, "/commands/lock", "state", locked ? "1" : "0", NULL);
-		bonobo_ui_component_set_prop(popup, "/commands/lock", "inconsistent", inconsistent ? "1" : "0", NULL);
+
+		bonobo_ui_component_set_prop(popup, "/commands/lock", "inconsistent", inconsistent ? "1" : "0", NULL); /* FIXME : Doesn't work */
+
+		bonobo_ui_component_set_prop(popup, "/commands/show", "sensitive", visible_writable ? "1" : "0", NULL);
+		bonobo_ui_component_set_prop(popup, "/commands/lock", "sensitive", locked_writable ? "1" : "0", NULL);
 	}
 }
 
@@ -343,11 +359,13 @@ void stickynotes_applet_do_default_action()
 			break;
 
 		case STICKYNOTES_SET_VISIBLE:
-			gconf_client_set_bool(stickynotes->gconf, GCONF_PATH "/settings/visible", !visible, NULL);
+			if (gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/settings/visible", NULL))
+				gconf_client_set_bool(stickynotes->gconf, GCONF_PATH "/settings/visible", !visible, NULL);
 			break;
 
 		case STICKYNOTES_SET_LOCKED:
-			gconf_client_set_bool(stickynotes->gconf, GCONF_PATH "/settings/locked", !locked, NULL);
+			if (gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/settings/locked", NULL))
+				gconf_client_set_bool(stickynotes->gconf, GCONF_PATH "/settings/locked", !locked, NULL);
 			break;
 	}
 }
